@@ -18,7 +18,9 @@
 #include <liblangtag/lt-database.h>
 #include <liblangtag/lt-ext-module.h>
 #include <liblangtag/lt-extension.h>
+#include <liblangtag/lt-iter.h>
 #include <liblangtag/lt-list.h>
+#include <liblangtag/lt-redundant.h>
 #include <liblangtag/lt-string.h>
 #include <liblangtag/lt-tag.h>
 #undef __LANGTAG_H__INSIDE
